@@ -2,7 +2,7 @@ package Net::DNS::RR::A;
 
 use strict;
 use warnings;
-our $VERSION = (qw$Id: A.pm 1896 2023-01-30 12:59:25Z willem $)[2];
+our $VERSION = (qw$Id: A.pm 1972 2024-04-21 08:13:19Z willem $)[2];
 
 use base qw(Net::DNS::RR);
 
@@ -128,6 +128,6 @@ DEALINGS IN THE SOFTWARE.
 =head1 SEE ALSO
 
 L<perl> L<Net::DNS> L<Net::DNS::RR>
-L<RFC1035(3.4.1)|https://tools.ietf.org/html/rfc1035>
+L<RFC1035(3.4.1)|https://iana.org/go/rfc1035#section-3.4.1>
 
 =cut
